package net.wanji.common.enums;
import lombok.Getter;

import java.util.*;

public class StrategyAndMetricsEnum {

    @Getter
    public enum Strategy {
        BALANCE("100030", "均衡调控"),
        EFFICIENCY("100152", "效率提升"),
        SECURITY("100010", "安全保障");

        private final String code;
        private final String msg;

        Strategy(String code, String msg) {
            this.code = code;
            this.msg = msg;
        }

        public static String getMsgByCode(String code) {
            for (Strategy value : Strategy.values()) {
                if (value.code.equals(code)) {
                    return value.msg;
                }
            }
            return null;
        }

    }

    @Getter
    public enum Metrics {
        NO_STOP_RATE("1", "不停车通过率", "%", "noStopRate"),
        STOP_RATE("2", "停车通过率", "%", "oneStopRate"),
        AVERAGE_DELAY("3", "平均延误", "s", "delayTime"),
        MAX_QUEUE_LENGTH("4", "最大排队长度", "m", "queueLength"),
        STOP_TIMES("5", "停车次数", "次", "stopTimes"),
        AVERAGE_SPEED("6", "平均速度", "km/h", "speed"),
        GREEN_LIGHT_EFFICIENCY("7", "绿灯有效利用率", "%", "greenLightEfficiency"),
        SATURATION("8", "饱和度", "", "sturation"),
        LOAD_BALANCE("9", "负载均衡度", "", "loadBalance"),
        EFFUSION_RATE("10", "溢流率", "%", "effusionRate"),
        CLEAR_RATE("11", "绿灯间隔清空率", "%", "clearRate"),
        EMERGENCY_COUNT("12", "三急一速数量", "", "emergencyCount"),
        EMPTY_DISCHARGES("13", "空放次数", "次", "emptyDischarges");

        private final String code;
        private final String description;
        private final String unit;
        private final String field; // 实体类中的字段名


        Metrics(String code, String description, String unit, String field) {
            this.code = code;
            this.description = description;
            this.unit = unit;
            this.field = field;
        }

        public static String getFieldByCode(String code) {
            for (Metrics value : Metrics.values()) {
                if (value.code.equals(code)) {
                    return value.field;
                }
            }
            return null;
        }

        public static String getNameByCode(String code) {
            for (Metrics value : Metrics.values()) {
                if (value.code.equals(code)) {
                    return value.description;
                }
            }
            return null;
        }

        public static Metrics getEnumByCode(String code) {
            for (Metrics value : Metrics.values()) {
                if (value.code.equals(code)) {
                    return value;
                }
            }
            return null;
        }
    }

    public static final Map<Strategy, List<Metrics>> STRATEGY_METRICS_MAP;

    static {
        Map<Strategy, List<Metrics>> map = new HashMap<>();
        map.put(Strategy.EFFICIENCY, Arrays.asList(
                Metrics.NO_STOP_RATE,
                Metrics.STOP_RATE,
                Metrics.AVERAGE_DELAY,
                Metrics.MAX_QUEUE_LENGTH,
                Metrics.STOP_TIMES,
                Metrics.AVERAGE_SPEED
        ));
        map.put(Strategy.BALANCE, Arrays.asList(
                Metrics.GREEN_LIGHT_EFFICIENCY,
                Metrics.SATURATION,
                Metrics.LOAD_BALANCE
        ));
        map.put(Strategy.SECURITY, Arrays.asList(
                Metrics.EFFUSION_RATE,
                Metrics.CLEAR_RATE,
                Metrics.EMERGENCY_COUNT
        ));
        STRATEGY_METRICS_MAP = Collections.unmodifiableMap(map);
    }

    public static void main(String[] args) {
        // 示例：获取"效率提升"策略的所有指标
        List<Metrics> efficiencyMetrics = STRATEGY_METRICS_MAP.get(Strategy.EFFICIENCY);
        System.out.println("效率提升的指标有：");
        for (Metrics metric : efficiencyMetrics) {
            System.out.println(metric.getDescription());
        }
    }
}
